﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using NPersistence;

namespace NPAExample
{
    class Program
    {
        static void Main(string[] args)
        {
            try
            {
                runTest();
            }
            catch (Exception e)
            {
                Console.WriteLine("GOT EXCEPTION");
                Console.WriteLine(e.Message);
                Console.WriteLine(e.StackTrace);
                Console.WriteLine("************");
                Console.WriteLine(e.InnerException);
            }
            Console.ReadKey();
        }

        private static EntityManager em;
        private static EntityManagerFactory emf;

        public static EntityManager getEm()
        {
            if (em == null)
            {
                emf = Persistence.CreateEntityManagerFactory("examplePersistenceUnit");
                em = emf.CreateEntityManager();
            }
            return em;
        }

        private static void runTest()
        {
            EntityManager em = getEm();

            Company npaInc = new Company();
            npaInc.name = "npaInc";
            npaInc.address = new Address() { city = "NY", street = "45th", number = 23 };
            npaInc.employeeList = new List<Employee>();

            Employee jon = new Employee();
            jon.name = "jon" + System.DateTime.UtcNow.Millisecond;
            jon.nickName = "jonny";
            jon.birthDate = DateTime.Now;

            Employee jack = new Employee();
            jack.name = "jack" + System.DateTime.UtcNow.Millisecond;
            jack.nickName = "jacky";
            jack.birthDate = DateTime.Now;

            npaInc.employeeList.Add(jon);
            npaInc.employeeList.Add(jack);

            em.GetTransaction().Begin();
            em.Persist(npaInc);
            em.Flush();
            em.GetTransaction().Commit();
            em.Clear();

            Company comp = em.Find<Company>(typeof(Company), npaInc.id);
            if (comp.employeeList.Count != 2)
            {
                throw new Exception("2 entities are expected. Got " + comp.employeeList.Count);
            }
            Console.WriteLine("######################### persisted objects ##############################");
            Console.WriteLine(comp.SayHello());
            Console.WriteLine(((Employee)comp.employeeList[0]).SayHello());
            Console.WriteLine(((Employee)comp.employeeList[1]).SayHello());
        }
    }
}
